==> _private_core_network-1.0.14.tar.gz: lib/network_resources/model/pro_info.dart <==
import '_model.dart';

class ProInfo {
  int? id;
  String? firebaseId;
  String? username;
  String? token;
  String? uniqueId;
  String? firstName;
  String? lastName;
  String? displayName;
  String? website;
  String? categorie;
  String? profession;
  String? rating;
  String? email;
  String? phone1;
  String? phone2;
  String? street1;
  String? street2;
  String? companyName;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? countryCode;
  double? lat;
  double? lng;
  String? colorCode;
  String? thumbnail;
  int? createdAt;
  int? signedAt;
  String? google;
  String? facebook;
  String? twitter;
  String? pinterest;
  String? instagram;
  String? linkedin;
  String? aboutMe;
  int? google2FaFlg;
  String? google2FaSecretKey;
  int? usedStorageSpace;
  String? gender;
  String? ageRange;
  String? phoneCode;
  String? subscriptionPlanId;
  int? allowChat;
  String? planName;
  String? mainLanguage;
  String? interfaceLanguageCode;
  List<dynamic>? secondaryLanguages;
  int? reliability;
  int? events;
  String? organisation;
  String? roleName;
  List<dynamic>? permissions;
  int? smsAllowed;
  int? freeSms;
  String? currency;
  String? billingName;
  String? vatNumber;
  String? companyNumber;
  String? organisationThumbnail;
  int? timeBeforeStartTracking;
  int? distanceBeforeStartTracking;
  String? registerFrom;
  int? isHomelidoAgent;
  int? industryId;
  int? allowGeolocation;
  String? dateFormat;
  String? timeFormat;
  MainSubcatInfo? mainSubcatInfo;
  String? industryName;
  String? kisblePublicThumbnailUrl;
  String? internalArckipelNote;
  List<PaymentBillingInfo>? billingInfos;

  bool get isUserVersion => false;

  String get fChar => displayName == null || displayName!.isEmpty
      ? ''
      : displayName!.split('').first;

  ProInfo(
      {this.id,
      this.firebaseId,
      this.username,
      this.token,
      this.uniqueId,
      this.firstName,
      this.lastName,
      this.displayName,
      this.website,
      this.categorie,
      this.profession,
      this.rating,
      this.email,
      this.phone1,
      this.phone2,
      this.street1,
      this.street2,
      this.companyName,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.countryCode,
      this.lat,
      this.lng,
      this.colorCode,
      this.thumbnail,
      this.createdAt,
      this.signedAt,
      this.google,
      this.facebook,
      this.twitter,
      this.pinterest,
      this.instagram,
      this.linkedin,
      this.aboutMe,
      this.google2FaFlg,
      this.google2FaSecretKey,
      this.usedStorageSpace,
      this.gender,
      this.ageRange,
      this.phoneCode,
      this.subscriptionPlanId,
      this.allowChat,
      this.planName,
      this.mainLanguage,
      this.interfaceLanguageCode,
      this.secondaryLanguages,
      this.reliability,
      this.events,
      this.organisation,
      this.roleName,
      this.permissions,
      this.smsAllowed,
      this.freeSms,
      this.currency,
      this.billingName,
      this.vatNumber,
      this.companyNumber,
      this.organisationThumbnail,
      this.timeBeforeStartTracking,
      this.distanceBeforeStartTracking,
      this.registerFrom,
      this.isHomelidoAgent,
      this.industryId,
      this.allowGeolocation,
      this.dateFormat,
      this.timeFormat,
      this.mainSubcatInfo,
      this.industryName,
      this.billingInfos,
      this.internalArckipelNote,
      this.kisblePublicThumbnailUrl});

  ProInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      this.id = json["id"];
    }
    if (json["firebaseId"] is String) {
      this.firebaseId = json["firebaseId"];
    }
    if (json["username"] is String) {
      this.username = json["username"];
    }
    if (json["token"] is String) {
      this.token = json["token"];
    }
    if (json["uniqueId"] is String) {
      this.uniqueId = json["uniqueId"];
    }
    if (json["firstName"] is String) {
      this.firstName = json["firstName"];
    }
    if (json["lastName"] is String) {
      this.lastName = json["lastName"];
    }
    if (json["displayName"] is String) {
      this.displayName = json["displayName"];
    }
    if (json["website"] is String) {
      this.website = json["website"];
    }
    if (json["categorie"] is String) {
      this.categorie = json["categorie"];
    }
    if (json["profession"] is String) {
      this.profession = json["profession"];
    }
    if (json["rating"] is String) {
      this.rating = json["rating"];
    }
    if (json["email"] is String) {
      this.email = json["email"];
    }
    if (json["phone1"] is String) {
      this.phone1 = json["phone1"];
    }
    if (json["phone2"] is String) {
      this.phone2 = json["phone2"];
    }
    if (json["street1"] is String) {
      this.street1 = json["street1"];
    }
    if (json["street2"] is String) {
      this.street2 = json["street2"];
    }
    if (json["companyName"] is String) {
      this.companyName = json["companyName"];
    }
    if (json["zip"] is String) {
      this.zip = json["zip"];
    }
    if (json["city"] is String) {
      this.city = json["city"];
    }
    if (json["state"] is String) {
      this.state = json["state"];
    }
    if (json["country"] is String) {
      this.country = json["country"];
    }
    if (json["countryCode"] is String) {
      this.countryCode = json["countryCode"];
    }
    if (json["lat"] is double) {
      this.lat = json["lat"];
    }
    if (json["lng"] is double) {
      this.lng = json["lng"];
    }
    if (json["colorCode"] is String) {
      this.colorCode = json["colorCode"];
    }
    if (json["thumbnail"] is String) {
      this.thumbnail = json["thumbnail"];
    }
    if (json["createdAt"] is int) {
      this.createdAt = json["createdAt"];
    }
    if (json["signedAt"] is int) {
      this.signedAt = json["signedAt"];
    }
    if (json["google"] is String) {
      this.google = json["google"];
    }
    if (json["facebook"] is String) {
      this.facebook = json["facebook"];
    }
    if (json["twitter"] is String) {
      this.twitter = json["twitter"];
    }
    if (json["pinterest"] is String) {
      this.pinterest = json["pinterest"];
    }
    if (json["instagram"] is String) {
      this.instagram = json["instagram"];
    }
    if (json["linkedin"] is String) {
      this.linkedin = json["linkedin"];
    }
    if (json["aboutMe"] is String) {
      this.aboutMe = json["aboutMe"];
    }
    if (json["google2FaFlg"] is int) {
      this.google2FaFlg = json["google2FaFlg"];
    }
    if (json["google2FaSecretKey"] is String) {
      this.google2FaSecretKey = json["google2FaSecretKey"];
    }
    if (json["usedStorageSpace"] is int) {
      this.usedStorageSpace = json["usedStorageSpace"];
    }
    if (json["gender"] is String) {
      this.gender = json["gender"];
    }
    if (json["ageRange"] is String) {
      this.ageRange = json["ageRange"];
    }
    if (json["phoneCode"] is String) {
      this.phoneCode = json["phoneCode"];
    }
    if (json["subscriptionPlanId"] is String) {
      this.subscriptionPlanId = json["subscriptionPlanId"];
    }
    if (json["allowChat"] is int) {
      this.allowChat = json["allowChat"];
    }
    if (json["planName"] is String) {
      this.planName = json["planName"];
    }
    if (json["mainLanguage"] is String) {
      this.mainLanguage = json["mainLanguage"];
    }
    if (json["interfaceLanguageCode"] is String) {
      this.interfaceLanguageCode = json["interfaceLanguageCode"];
    }
    if (json["secondaryLanguages"] is List) {
      this.secondaryLanguages = json["secondaryLanguages"] ?? [];
    }
    if (json["reliability"] is int) {
      this.reliability = json["reliability"];
    }
    if (json["events"] is int) {
      this.events = json["events"];
    }
    if (json["organisation"] is String) {
      this.organisation = json["organisation"];
    }
    if (json["roleName"] is String) {
      this.roleName = json["roleName"];
    }
    if (json["permissions"] is List) {
      this.permissions = json["permissions"] ?? [];
    }
    if (json["smsAllowed"] is int) {
      this.smsAllowed = json["smsAllowed"];
    }
    if (json["freeSms"] is int) {
      this.freeSms = json["freeSms"];
    }
    if (json["currency"] is String) {
      this.currency = json["currency"];
    }
    if (json["billingName"] is String) {
      this.billingName = json["billingName"];
    }
    if (json["vatNumber"] is String) {
      this.vatNumber = json["vatNumber"];
    }
    if (json["companyNumber"] is String) {
      this.companyNumber = json["companyNumber"];
    }
    if (json["organisationThumbnail"] is String) {
      this.organisationThumbnail = json["organisationThumbnail"];
    }
    if (json["timeBeforeStartTracking"] is int) {
      this.timeBeforeStartTracking = json["timeBeforeStartTracking"];
    }
    if (json["distanceBeforeStartTracking"] is int) {
      this.distanceBeforeStartTracking = json["distanceBeforeStartTracking"];
    }
    if (json["registerFrom"] is String) {
      this.registerFrom = json["registerFrom"];
    }
    if (json["isHomelidoAgent"] is int) {
      this.isHomelidoAgent = json["isHomelidoAgent"];
    }
    if (json["industryId"] is int) {
      this.industryId = json["industryId"];
    }
    if (json["allowGeolocation"] is int) {
      this.allowGeolocation = json["allowGeolocation"];
    }
    if (json["dateFormat"] is String) {
      this.dateFormat = json["dateFormat"];
    }
    if (json["timeFormat"] is String) {
      this.timeFormat = json["timeFormat"];
    }
    if (json["mainSubcatInfo"] is Map) {
      this.mainSubcatInfo = json["mainSubcatInfo"] == null
          ? null
          : MainSubcatInfo.fromJson(json["mainSubcatInfo"]);
    }
    if (json["industryName"] is String) {
      this.industryName = json["industryName"];
    }

    if (json["billingInfos"] is List) {
      this.billingInfos = (json["billingInfos"] as List)
          .map((e) => PaymentBillingInfo.fromJson(e))
          .toList();
    }
    if (json["internalArckipelNote"] is String) {
      this.internalArckipelNote = json["internalArckipelNote"];
    }
    if (json["kisblePublicThumbnailUrl"] is String) {
      this.kisblePublicThumbnailUrl = json["kisblePublicThumbnailUrl"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = this.id;
    data["firebaseId"] = this.firebaseId;
    data["username"] = this.username;
    data["token"] = this.token;
    data["uniqueId"] = this.uniqueId;
    data["firstName"] = this.firstName;
    data["lastName"] = this.lastName;
    data["displayName"] = this.displayName;
    data["website"] = this.website;
    data["categorie"] = this.categorie;
    data["profession"] = this.profession;
    data["rating"] = this.rating;
    data["email"] = this.email;
    data["phone1"] = this.phone1;
    data["phone2"] = this.phone2;
    data["street1"] = this.street1;
    data["street2"] = this.street2;
    data["companyName"] = this.companyName;
    data["zip"] = this.zip;
    data["city"] = this.city;
    data["state"] = this.state;
    data["country"] = this.country;
    data["countryCode"] = this.countryCode;
    data["lat"] = this.lat;
    data["lng"] = this.lng;
    data["colorCode"] = this.colorCode;
    data["thumbnail"] = this.thumbnail;
    data["createdAt"] = this.createdAt;
    data["signedAt"] = this.signedAt;
    data["google"] = this.google;
    data["facebook"] = this.facebook;
    data["twitter"] = this.twitter;
    data["pinterest"] = this.pinterest;
    data["instagram"] = this.instagram;
    data["linkedin"] = this.linkedin;
    data["aboutMe"] = this.aboutMe;
    data["google2FaFlg"] = this.google2FaFlg;
    data["google2FaSecretKey"] = this.google2FaSecretKey;
    data["usedStorageSpace"] = this.usedStorageSpace;
    data["gender"] = this.gender;
    data["ageRange"] = this.ageRange;
    data["phoneCode"] = this.phoneCode;
    data["subscriptionPlanId"] = this.subscriptionPlanId;
    data["allowChat"] = this.allowChat;
    data["planName"] = this.planName;
    data["mainLanguage"] = this.mainLanguage;
    data["interfaceLanguageCode"] = this.interfaceLanguageCode;
    if (this.secondaryLanguages != null) {
      data["secondaryLanguages"] = this.secondaryLanguages;
    }
    if (this.billingInfos != null) {
      data["billingInfos"] = this.billingInfos!.map((e) => e.toJson());
    }
    data["reliability"] = this.reliability;
    data["events"] = this.events;
    data["organisation"] = this.organisation;
    data["roleName"] = this.roleName;
    if (this.permissions != null) {
      data["permissions"] = this.permissions;
    }
    data["smsAllowed"] = this.smsAllowed;
    data["freeSms"] = this.freeSms;
    data["currency"] = this.currency;
    data["billingName"] = this.billingName;
    data["vatNumber"] = this.vatNumber;
    data["companyNumber"] = this.companyNumber;
    data["organisationThumbnail"] = this.organisationThumbnail;
    data["timeBeforeStartTracking"] = this.timeBeforeStartTracking;
    data["distanceBeforeStartTracking"] = this.distanceBeforeStartTracking;
    data["registerFrom"] = this.registerFrom;
    data["isHomelidoAgent"] = this.isHomelidoAgent;
    data["industryId"] = this.industryId;
    data["allowGeolocation"] = this.allowGeolocation;
    data["dateFormat"] = this.dateFormat;
    data["timeFormat"] = this.timeFormat;
    if (this.mainSubcatInfo != null) {
      data["mainSubcatInfo"] = this.mainSubcatInfo?.toJson();
    }
    data["industryName"] = this.industryName;
    data["kisblePublicThumbnailUrl"] = this.kisblePublicThumbnailUrl;
    data["internalArckipelNote"] = this.internalArckipelNote;
    return data;
  }
}

class MainSubcatInfo {
  int? id;
  int? maincatId;
  String? subcatName;
  String? colorCode;
  String? pictureUrl;
  int? display;

  MainSubcatInfo(
      {this.id,
      this.maincatId,
      this.subcatName,
      this.colorCode,
      this.pictureUrl,
      this.display});

  MainSubcatInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      this.id = json["id"];
    }
    if (json["maincatId"] is int) {
      this.maincatId = json["maincatId"];
    }
    if (json["subcatName"] is String) {
      this.subcatName = json["subcatName"];
    }
    if (json["colorCode"] is String) {
      this.colorCode = json["colorCode"];
    }
    if (json["pictureUrl"] is String) {
      this.pictureUrl = json["pictureUrl"];
    }
    if (json["display"] is int) {
      this.display = json["display"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = this.id;
    data["maincatId"] = this.maincatId;
    data["subcatName"] = this.subcatName;
    data["colorCode"] = this.colorCode;
    data["pictureUrl"] = this.pictureUrl;
    data["display"] = this.display;
    return data;
  }
}

class GetProDetailModel {
  GetProDetailModel({
    required this.proInfo,
  });

  ProInfo proInfo;

  factory GetProDetailModel.fromJson(Map<String, dynamic> json) =>
      GetProDetailModel(
        proInfo: ProInfo.fromJson(json["values"]),
      );

  Map<String, dynamic> toJson() => {
        "values": proInfo.toJson(),
      };
}

==> _private_core_network-1.2.25.tar.gz: lib/network_resources/model/pro_info.dart <==
import '_model.dart';

class ProInfo {
  int? id;
  String? firebaseId;
  String? username;
  String? token;
  String? uniqueId;
  String? firstName;
  String? lastName;
  String? displayName;
  String? website;
  String? categorie;
  String? profession;
  String? rating;
  String? email;
  String? phone1;
  String? phone2;
  String? street1;
  String? street2;
  String? companyName;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? countryCode;
  double? lat;
  double? lng;
  String? colorCode;
  String? thumbnail;
  int? createdAt;
  int? signedAt;
  String? google;
  String? facebook;
  String? twitter;
  String? pinterest;
  String? instagram;
  String? linkedin;
  String? aboutMe;
  int? google2FaFlg;
  String? google2FaSecretKey;
  int? usedStorageSpace;
  String? gender;
  String? ageRange;
  String? phoneCode;
  String? subscriptionPlanId;
  int? allowChat;
  String? planName;
  String? mainLanguage;
  String? interfaceLanguageCode;
  List<dynamic>? secondaryLanguages;
  int? reliability;
  int? events;
  String? organisation;
  String? roleName;
  List<dynamic>? permissions;
  int? smsAllowed;
  int? freeSms;
  String? currency;
  String? billingName;
  String? vatNumber;
  String? companyNumber;
  String? organisationThumbnail;
  int? timeBeforeStartTracking;
  int? distanceBeforeStartTracking;
  String? registerFrom;
  int? isHomelidoAgent;
  int? industryId;
  int? allowGeolocation;
  String? dateFormat;
  String? timeFormat;
  MainSubcatInfo? mainSubcatInfo;
  String? industryName;
  String? kisblePublicThumbnailUrl;
  String? internalArckipelNote;
  List<PaymentBillingInfo>? billingInfos;

  TokenResponseLoginMqtt? mqtt;

  bool get isUserVersion => false;

  String get fChar => displayName == null || displayName!.isEmpty
      ? ''
      : displayName!.split('').first;

  ProInfo({
    this.id,
    this.firebaseId,
    this.username,
    this.token,
    this.uniqueId,
    this.firstName,
    this.lastName,
    this.displayName,
    this.website,
    this.categorie,
    this.profession,
    this.rating,
    this.email,
    this.phone1,
    this.phone2,
    this.street1,
    this.street2,
    this.companyName,
    this.zip,
    this.city,
    this.state,
    this.country,
    this.countryCode,
    this.lat,
    this.lng,
    this.colorCode,
    this.thumbnail,
    this.createdAt,
    this.signedAt,
    this.google,
    this.facebook,
    this.twitter,
    this.pinterest,
    this.instagram,
    this.linkedin,
    this.aboutMe,
    this.google2FaFlg,
    this.google2FaSecretKey,
    this.usedStorageSpace,
    this.gender,
    this.ageRange,
    this.phoneCode,
    this.subscriptionPlanId,
    this.allowChat,
    this.planName,
    this.mainLanguage,
    this.interfaceLanguageCode,
    this.secondaryLanguages,
    this.reliability,
    this.events,
    this.organisation,
    this.roleName,
    this.permissions,
    this.smsAllowed,
    this.freeSms,
    this.currency,
    this.billingName,
    this.vatNumber,
    this.companyNumber,
    this.organisationThumbnail,
    this.timeBeforeStartTracking,
    this.distanceBeforeStartTracking,
    this.registerFrom,
    this.isHomelidoAgent,
    this.industryId,
    this.allowGeolocation,
    this.dateFormat,
    this.timeFormat,
    this.mainSubcatInfo,
    this.industryName,
    this.billingInfos,
    this.internalArckipelNote,
    this.kisblePublicThumbnailUrl,
    this.mqtt,
  });

  ProInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      this.id = json["id"];
    }
    if (json["firebaseId"] is String) {
      this.firebaseId = json["firebaseId"];
    }
    if (json["username"] is String) {
      this.username = json["username"];
    }
    if (json["token"] is String) {
      this.token = json["token"];
    }
    if (json["uniqueId"] is String) {
      this.uniqueId = json["uniqueId"];
    }
    if (json["firstName"] is String) {
      this.firstName = json["firstName"];
    }
    if (json["lastName"] is String) {
      this.lastName = json["lastName"];
    }
    if (json["displayName"] is String) {
      this.displayName = json["displayName"];
    }
    if (json["website"] is String) {
      this.website = json["website"];
    }
    if (json["categorie"] is String) {
      this.categorie = json["categorie"];
    }
    if (json["profession"] is String) {
      this.profession = json["profession"];
    }
    if (json["rating"] is String) {
      this.rating = json["rating"];
    }
    if (json["email"] is String) {
      this.email = json["email"];
    }
    if (json["phone1"] is String) {
      this.phone1 = json["phone1"];
    }
    if (json["phone2"] is String) {
      this.phone2 = json["phone2"];
    }
    if (json["street1"] is String) {
      this.street1 = json["street1"];
    }
    if (json["street2"] is String) {
      this.street2 = json["street2"];
    }
    if (json["companyName"] is String) {
      this.companyName = json["companyName"];
    }
    if (json["zip"] is String) {
      this.zip = json["zip"];
    }
    if (json["city"] is String) {
      this.city = json["city"];
    }
    if (json["state"] is String) {
      this.state = json["state"];
    }
    if (json["country"] is String) {
      this.country = json["country"];
    }
    if (json["countryCode"] is String) {
      this.countryCode = json["countryCode"];
    }
    if (json["lat"] is double) {
      this.lat = json["lat"];
    }
    if (json["lng"] is double) {
      this.lng = json["lng"];
    }
    if (json["colorCode"] is String) {
      this.colorCode = json["colorCode"];
    }
    if (json["thumbnail"] is String) {
      this.thumbnail = json["thumbnail"];
    }
    if (json["createdAt"] is int) {
      this.createdAt = json["createdAt"];
    }
    if (json["signedAt"] is int) {
      this.signedAt = json["signedAt"];
    }
    if (json["google"] is String) {
      this.google = json["google"];
    }
    if (json["facebook"] is String) {
      this.facebook = json["facebook"];
    }
    if (json["twitter"] is String) {
      this.twitter = json["twitter"];
    }
    if (json["pinterest"] is String) {
      this.pinterest = json["pinterest"];
    }
    if (json["instagram"] is String) {
      this.instagram = json["instagram"];
    }
    if (json["linkedin"] is String) {
      this.linkedin = json["linkedin"];
    }
    if (json["aboutMe"] is String) {
      this.aboutMe = json["aboutMe"];
    }
    if (json["google2FaFlg"] is int) {
      this.google2FaFlg = json["google2FaFlg"];
    }
    if (json["google2FaSecretKey"] is String) {
      this.google2FaSecretKey = json["google2FaSecretKey"];
    }
    if (json["usedStorageSpace"] is int) {
      this.usedStorageSpace = json["usedStorageSpace"];
    }
    if (json["gender"] is String) {
      this.gender = json["gender"];
    }
    if (json["ageRange"] is String) {
      this.ageRange = json["ageRange"];
    }
    if (json["phoneCode"] is String) {
      this.phoneCode = json["phoneCode"];
    }
    if (json["subscriptionPlanId"] is String) {
      this.subscriptionPlanId = json["subscriptionPlanId"];
    }
    if (json["allowChat"] is int) {
      this.allowChat = json["allowChat"];
    }
    if (json["planName"] is String) {
      this.planName = json["planName"];
    }
    if (json["mainLanguage"] is String) {
      this.mainLanguage = json["mainLanguage"];
    }
    if (json["interfaceLanguageCode"] is String) {
      this.interfaceLanguageCode = json["interfaceLanguageCode"];
    }
    if (json["secondaryLanguages"] is List) {
      this.secondaryLanguages = json["secondaryLanguages"] ?? [];
    }
    if (json["reliability"] is int) {
      this.reliability = json["reliability"];
    }
    if (json["events"] is int) {
      this.events = json["events"];
    }
    if (json["organisation"] is String) {
      this.organisation = json["organisation"];
    }
    if (json["roleName"] is String) {
      this.roleName = json["roleName"];
    }
    if (json["permissions"] is List) {
      this.permissions = json["permissions"] ?? [];
    }
    if (json["smsAllowed"] is int) {
      this.smsAllowed = json["smsAllowed"];
    }
    if (json["freeSms"] is int) {
      this.freeSms = json["freeSms"];
    }
    if (json["currency"] is String) {
      this.currency = json["currency"];
    }
    if (json["billingName"] is String) {
      this.billingName = json["billingName"];
    }
    if (json["vatNumber"] is String) {
      this.vatNumber = json["vatNumber"];
    }
    if (json["companyNumber"] is String) {
      this.companyNumber = json["companyNumber"];
    }
    if (json["organisationThumbnail"] is String) {
      this.organisationThumbnail = json["organisationThumbnail"];
    }
    if (json["timeBeforeStartTracking"] is int) {
      this.timeBeforeStartTracking = json["timeBeforeStartTracking"];
    }
    if (json["distanceBeforeStartTracking"] is int) {
      this.distanceBeforeStartTracking = json["distanceBeforeStartTracking"];
    }
    if (json["registerFrom"] is String) {
      this.registerFrom = json["registerFrom"];
    }
    if (json["isHomelidoAgent"] is int) {
      this.isHomelidoAgent = json["isHomelidoAgent"];
    }
    if (json["industryId"] is int) {
      this.industryId = json["industryId"];
    }
    if (json["allowGeolocation"] is int) {
      this.allowGeolocation = json["allowGeolocation"];
    }
    if (json["dateFormat"] is String) {
      this.dateFormat = json["dateFormat"];
    }
    if (json["timeFormat"] is String) {
      this.timeFormat = json["timeFormat"];
    }
    if (json["mainSubcatInfo"] is Map) {
      this.mainSubcatInfo = json["mainSubcatInfo"] == null
          ? null
          : MainSubcatInfo.fromJson(json["mainSubcatInfo"]);
    }
    if (json["industryName"] is String) {
      this.industryName = json["industryName"];
    }

    if (json["billingInfos"] is List) {
      this.billingInfos = (json["billingInfos"] as List)
          .map((e) => PaymentBillingInfo.fromJson(e))
          .toList();
    }
    if (json["internalArckipelNote"] is String) {
      this.internalArckipelNote = json["internalArckipelNote"];
    }
    if (json["kisblePublicThumbnailUrl"] is String) {
      this.kisblePublicThumbnailUrl = json["kisblePublicThumbnailUrl"];
    }

    mqtt = json["mqtt"] == null
        ? null
        : TokenResponseLoginMqtt.fromJson(json["mqtt"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = this.id;
    data["firebaseId"] = this.firebaseId;
    data["username"] = this.username;
    data["token"] = this.token;
    data["uniqueId"] = this.uniqueId;
    data["firstName"] = this.firstName;
    data["lastName"] = this.lastName;
    data["displayName"] = this.displayName;
    data["website"] = this.website;
    data["categorie"] = this.categorie;
    data["profession"] = this.profession;
    data["rating"] = this.rating;
    data["email"] = this.email;
    data["phone1"] = this.phone1;
    data["phone2"] = this.phone2;
    data["street1"] = this.street1;
    data["street2"] = this.street2;
    data["companyName"] = this.companyName;
    data["zip"] = this.zip;
    data["city"] = this.city;
    data["state"] = this.state;
    data["country"] = this.country;
    data["countryCode"] = this.countryCode;
    data["lat"] = this.lat;
    data["lng"] = this.lng;
    data["colorCode"] = this.colorCode;
    data["thumbnail"] = this.thumbnail;
    data["createdAt"] = this.createdAt;
    data["signedAt"] = this.signedAt;
    data["google"] = this.google;
    data["facebook"] = this.facebook;
    data["twitter"] = this.twitter;
    data["pinterest"] = this.pinterest;
    data["instagram"] = this.instagram;
    data["linkedin"] = this.linkedin;
    data["aboutMe"] = this.aboutMe;
    data["google2FaFlg"] = this.google2FaFlg;
    data["google2FaSecretKey"] = this.google2FaSecretKey;
    data["usedStorageSpace"] = this.usedStorageSpace;
    data["gender"] = this.gender;
    data["ageRange"] = this.ageRange;
    data["phoneCode"] = this.phoneCode;
    data["subscriptionPlanId"] = this.subscriptionPlanId;
    data["allowChat"] = this.allowChat;
    data["planName"] = this.planName;
    data["mainLanguage"] = this.mainLanguage;
    data["interfaceLanguageCode"] = this.interfaceLanguageCode;
    if (this.secondaryLanguages != null) {
      data["secondaryLanguages"] = this.secondaryLanguages;
    }
    if (this.billingInfos != null) {
      data["billingInfos"] = this.billingInfos!.map((e) => e.toJson());
    }
    data["reliability"] = this.reliability;
    data["events"] = this.events;
    data["organisation"] = this.organisation;
    data["roleName"] = this.roleName;
    if (this.permissions != null) {
      data["permissions"] = this.permissions;
    }
    data["smsAllowed"] = this.smsAllowed;
    data["freeSms"] = this.freeSms;
    data["currency"] = this.currency;
    data["billingName"] = this.billingName;
    data["vatNumber"] = this.vatNumber;
    data["companyNumber"] = this.companyNumber;
    data["organisationThumbnail"] = this.organisationThumbnail;
    data["timeBeforeStartTracking"] = this.timeBeforeStartTracking;
    data["distanceBeforeStartTracking"] = this.distanceBeforeStartTracking;
    data["registerFrom"] = this.registerFrom;
    data["isHomelidoAgent"] = this.isHomelidoAgent;
    data["industryId"] = this.industryId;
    data["allowGeolocation"] = this.allowGeolocation;
    data["dateFormat"] = this.dateFormat;
    data["timeFormat"] = this.timeFormat;
    if (this.mainSubcatInfo != null) {
      data["mainSubcatInfo"] = this.mainSubcatInfo?.toJson();
    }
    data["industryName"] = this.industryName;
    data["kisblePublicThumbnailUrl"] = this.kisblePublicThumbnailUrl;
    data["internalArckipelNote"] = this.internalArckipelNote;
    return data;
  }
}

class MainSubcatInfo {
  int? id;
  int? maincatId;
  String? subcatName;
  String? colorCode;
  String? pictureUrl;
  int? display;

  MainSubcatInfo(
      {this.id,
      this.maincatId,
      this.subcatName,
      this.colorCode,
      this.pictureUrl,
      this.display});

  MainSubcatInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      this.id = json["id"];
    }
    if (json["maincatId"] is int) {
      this.maincatId = json["maincatId"];
    }
    if (json["subcatName"] is String) {
      this.subcatName = json["subcatName"];
    }
    if (json["colorCode"] is String) {
      this.colorCode = json["colorCode"];
    }
    if (json["pictureUrl"] is String) {
      this.pictureUrl = json["pictureUrl"];
    }
    if (json["display"] is int) {
      this.display = json["display"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = this.id;
    data["maincatId"] = this.maincatId;
    data["subcatName"] = this.subcatName;
    data["colorCode"] = this.colorCode;
    data["pictureUrl"] = this.pictureUrl;
    data["display"] = this.display;
    return data;
  }
}

class GetProDetailModel {
  GetProDetailModel({
    required this.proInfo,
  });

  ProInfo proInfo;

  factory GetProDetailModel.fromJson(Map<String, dynamic> json) =>
      GetProDetailModel(
        proInfo: ProInfo.fromJson(json["values"]),
      );

  Map<String, dynamic> toJson() => {
        "values": proInfo.toJson(),
      };
}
